CCL: ccl_test_pyccl_interface Namespace Reference

CCL

Functions
ccl_test_pyccl_interface Namespace Reference

## Functions
def | reference_models ()
def | all_finite (vals)
def | check_background (cosmo)
def | check_power (cosmo)
def | check_massfunc (cosmo)
def | check_lsst_specs (cosmo)
def | check_cls (cosmo)
def | test_background ()
def | test_power ()
def | test_massfunc ()
def | test_lsst_specs ()
def | test_cls ()

## Function Documentation

## ◆ all_finite()

def ccl_test_pyccl_interface.all_finite | ( |  | vals | ) |

    Returns True if all elements are finite (i.e. not NaN or inf).

## ◆ check_background()

def ccl_test_pyccl_interface.check_background | ( |  | cosmo | ) |

    Check that background and growth functions can be run.

## ◆ check_cls()

def ccl_test_pyccl_interface.check_cls | ( |  | cosmo | ) |

    Check that cls functions can be run.

## ◆ check_lsst_specs()

def ccl_test_pyccl_interface.check_lsst_specs | ( |  | cosmo | ) |

    Check that lsst_specs functions can be run.

## ◆ check_massfunc()

def ccl_test_pyccl_interface.check_massfunc | ( |  | cosmo | ) |

    Check that mass function and supporting functions can be run.

## ◆ check_power()

def ccl_test_pyccl_interface.check_power | ( |  | cosmo | ) |

    Check that power spectrum and sigma functions can be run.

## ◆ reference_models()

def ccl_test_pyccl_interface.reference_models | ( |  | ) |

    Create a set of reference Cosmology() objects.

## ◆ test_background()

def ccl_test_pyccl_interface.test_background | ( |  | ) |

    Test background and growth functions in ccl.background.

## ◆ test_cls()

def ccl_test_pyccl_interface.test_cls | ( |  | ) |

    Test top-level functions in pyccl.cls module.

## ◆ test_lsst_specs()

def ccl_test_pyccl_interface.test_lsst_specs | ( |  | ) |

    Test lsst specs module.

## ◆ test_massfunc()

def ccl_test_pyccl_interface.test_massfunc | ( |  | ) |

    Test mass function and supporting functions.

## ◆ test_power()

def ccl_test_pyccl_interface.test_power | ( |  | ) |

    Test power spectrum and sigma functions in ccl.power.